@@ -1,15 +1,15 @@
 package Map::Tube::Pluggable;
 
-$Map::Tube::Pluggable::VERSION   = '2.80';
+$Map::Tube::Pluggable::VERSION   = '2.81';
 $Map::Tube::Pluggable::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
 
-Map::Tube::Pluggable - Wrapper for Map::Tube::Plugin::* packages.
+Map::Tube::Pluggable - Class to load plugins for Map::Tube.
 
 =head1 VERSION
 
-Version 2.80
+Version 2.81
 
 =cut
 
